`timescale 1ns / 1ps

module model_1645RT2 (A, D, nCE, nPE, nOE, T1, T2);  

input         nCE, nPE, nOE;
input         T1, T2;
input  [14:0] A;

inout  [7:0]  D;

wire [14:0] adr_MEM;
wire  [7:0] DIN_MEM;
wire  [7:0] DOUT_MEM;


assign adr_MEM = A;

buf (nCE_MEM, nCE);
buf (nPE_MEM, nPE);
buf (nOE_MEM, nOE);


reg [7:0] mem [32*1024-1:0];

reg [7:0] DOUT_MEM_reg;
reg        NOTIFY_REG;
reg [14:0] A_LAST_pr;
reg [7:0] Data;

integer i, j, k;

wire se, pe;


not (se, nCE_MEM);
not (pe, nPE_MEM);


assign D   = (~(nOE | nCE)) ? DOUT_MEM : 'hzz;
assign DIN_MEM = (~(nPE | nCE)) ? D : 'h00;

always @(*) if (~(nOE | nPE))
begin
$display("Error - invalid mode!!! nOE and nPE are both active_low, time =", $time);
$stop;
end


always @(*) if (!T1 | T2)
begin
$display("Error - invalid mode!!! T1 must be Ucc and T2 must be GND, time =", $time);
$stop;
end

always @(NOTIFY_REG)
begin
if (NOTIFY_REG)
 	begin 	
	$display("!!! Error - invalid mode!!! timing violation !!!");
	$stop;
	end
end

assign #99 DOUT_MEM = DOUT_MEM_reg;



always @(*) if (se & ~pe) DOUT_MEM_reg = mem[adr_MEM[14:0]];




initial begin
NOTIFY_REG<=1'b0;
  for (i=0;i<32768;i=i+1)
    mem[i] = 16'b0;  
end

wire [14:0] Adr;
assign Adr[14:0] = adr_MEM[14:0];
wire [7:0] Di;
assign Di[7:0] = DIN_MEM[7:0];

always @(pe or Adr or Di) begin
  if ((|Di & ( Adr !=  A_LAST_pr)) && nPE_MEM)
    mem[Adr[14:0]] = 40'hx;
  else if (pe && se && {T1,T2}==2'b10) begin 
    A_LAST_pr = Adr;
    Data=mem[Adr[14:0]];
    k=0;
    for(j=0;j<8;j=j+1)
      if (Di[j]) k=k+1;
    if (k==1)
      mem[Adr] = {Data[ 7] | Di[ 7], 
                      Data[ 6] | Di[ 6], 
                      Data[ 5] | Di[ 5], 
                      Data[ 4] | Di[ 4], 
                      Data[ 3] | Di[ 3], 
                      Data[ 2] | Di[ 2], 
                      Data[ 1] | Di[ 1], 
                      Data[ 0] | Di[ 0]}; 
    else if (k>1) begin
      $display ("Warning!!! Input data include more than one bit of unity!!!, time =", $time); 
      mem[Adr] = {Data[ 7] | (Di[ 7] & 1'bx),
                Data[ 6] | (Di[ 6] & 1'bx),
                Data[ 5] | (Di[ 5] & 1'bx),
                Data[ 4] | (Di[ 4] & 1'bx),
                Data[ 3] | (Di[ 3] & 1'bx),
                Data[ 2] | (Di[ 2] & 1'bx),
                Data[ 1] | (Di[ 1] & 1'bx),
                Data[ 0] | (Di[ 0] & 1'bx)};
    end
  end  

end


specify

specparam  pe_adr_MEM_SU = 0;
specparam  D_pe_HD   = 0;
specparam  pe_D_SU   = 299_000;	   //000
specparam  D_PWH      = 1_699_000;		//000
specparam  A_D_SU = 299_000, 				 //000
           A_D_HD = 4_999,
		   D_D_SU = 299_000; 	 				//000
		   

	$setup	(posedge pe ,  A[14], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[13], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[12], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[11], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[10], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[ 9], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[ 8], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[ 7], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[ 6], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[ 5], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[ 4], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[ 3], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[ 2], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[ 1], pe_adr_MEM_SU, NOTIFY_REG);
	$setup	(posedge pe ,  A[ 0], pe_adr_MEM_SU, NOTIFY_REG);
	


	$setup	(posedge pe , posedge Di[ 7], pe_D_SU, NOTIFY_REG);
	$setup	(posedge pe , posedge Di[ 6], pe_D_SU, NOTIFY_REG);
	$setup	(posedge pe , posedge Di[ 5], pe_D_SU, NOTIFY_REG);
	$setup	(posedge pe , posedge Di[ 4], pe_D_SU, NOTIFY_REG);
	$setup	(posedge pe , posedge Di[ 3], pe_D_SU, NOTIFY_REG);
	$setup	(posedge pe , posedge Di[ 2], pe_D_SU, NOTIFY_REG);
	$setup	(posedge pe , posedge Di[ 1], pe_D_SU, NOTIFY_REG);
	$setup	(posedge pe , posedge Di[ 0], pe_D_SU, NOTIFY_REG);


	$hold	(negedge Di[ 7] , negedge pe, D_pe_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , negedge pe, D_pe_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , negedge pe, D_pe_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , negedge pe, D_pe_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , negedge pe, D_pe_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , negedge pe, D_pe_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , negedge pe, D_pe_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , negedge pe, D_pe_HD, NOTIFY_REG);

	$setup	(A[ 0] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 1] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 2] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 3] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 4] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 5] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 6] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 7] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 8] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 9] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[10] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[11] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[12] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);  
	$setup	(A[13] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	$setup	(A[14] , posedge Di[ 0], A_D_SU,  NOTIFY_REG);
	
	$setup	(A[ 0] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 1] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 2] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 3] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 4] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 5] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 6] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 7] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 8] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 9] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[10] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[11] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[12] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);  
	$setup	(A[13] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[14] , posedge Di[ 1], A_D_SU,  NOTIFY_REG);                                      
	
	$setup	(A[ 0] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 1] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 2] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 3] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 4] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 5] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 6] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 7] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 8] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 9] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[10] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[11] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[12] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);   
	$setup	(A[13] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	$setup	(A[14] , posedge Di[ 2], A_D_SU,  NOTIFY_REG);
	
	$setup	(A[ 0] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 1] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 2] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 3] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 4] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 5] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 6] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 7] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 8] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 9] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[10] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[11] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[12] , posedge Di[ 3], A_D_SU,  NOTIFY_REG); 
	$setup	(A[13] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[14] , posedge Di[ 3], A_D_SU,  NOTIFY_REG);                                      
	
	$setup	(A[ 0] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 1] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 2] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 3] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 4] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 5] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 6] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 7] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 8] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 9] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[10] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[11] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[12] , posedge Di[ 4], A_D_SU,  NOTIFY_REG); 
	$setup	(A[13] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	$setup	(A[14] , posedge Di[ 4], A_D_SU,  NOTIFY_REG);
	
	$setup	(A[ 0] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 1] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 2] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 3] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 4] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 5] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 6] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 7] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 8] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 9] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[10] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[11] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[12] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);   
	$setup	(A[13] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[14] , posedge Di[ 5], A_D_SU,  NOTIFY_REG);                                      
	
	$setup	(A[ 0] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 1] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 2] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 3] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 4] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 5] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 6] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 7] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 8] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[ 9] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[10] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[11] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[12] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);    
	$setup	(A[13] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	$setup	(A[14] , posedge Di[ 6], A_D_SU,  NOTIFY_REG);
	
	$setup	(A[ 0] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 1] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 2] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 3] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 4] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 5] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 6] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 7] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 8] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[ 9] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[10] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[11] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[12] , posedge Di[ 7], A_D_SU,  NOTIFY_REG); 
	$setup	(A[13] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	$setup	(A[14] , posedge Di[ 7], A_D_SU,  NOTIFY_REG);                                      
	

                                    

  	$hold	(negedge Di[ 0] , A[ 0],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[ 1],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[ 2],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[ 3],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[ 4],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[ 5],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[ 6],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[ 7],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[ 8],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[ 9],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[10],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[11],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[12],  A_D_HD, NOTIFY_REG);	 
	$hold	(negedge Di[ 0] , A[13],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 0] , A[14],  A_D_HD, NOTIFY_REG);

	$hold	(negedge Di[ 1] , A[ 0],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[ 1],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[ 2],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[ 3],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[ 4],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[ 5],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[ 6],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[ 7],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[ 8],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[ 9],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[10],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[11],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[12],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[13],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 1] , A[14],  A_D_HD, NOTIFY_REG);

	$hold	(negedge Di[ 2] , A[ 0],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[ 1],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[ 2],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[ 3],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[ 4],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[ 5],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[ 6],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[ 7],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[ 8],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[ 9],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[10],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[11],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[12],  A_D_HD, NOTIFY_REG); 
	$hold	(negedge Di[ 2] , A[13],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 2] , A[14],  A_D_HD, NOTIFY_REG);

	$hold	(negedge Di[ 3] , A[ 0],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[ 1],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[ 2],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[ 3],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[ 4],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[ 5],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[ 6],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[ 7],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[ 8],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[ 9],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[10],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[11],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[12],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[13],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 3] , A[14],  A_D_HD, NOTIFY_REG);

	$hold	(negedge Di[ 4] , A[ 0],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[ 1],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[ 2],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[ 3],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[ 4],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[ 5],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[ 6],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[ 7],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[ 8],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[ 9],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[10],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[11],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[12],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[13],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 4] , A[14],  A_D_HD, NOTIFY_REG);

	$hold	(negedge Di[ 5] , A[ 0],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[ 1],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[ 2],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[ 3],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[ 4],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[ 5],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[ 6],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[ 7],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[ 8],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[ 9],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[10],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[11],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[12],  A_D_HD, NOTIFY_REG);	
	$hold	(negedge Di[ 5] , A[13],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 5] , A[14],  A_D_HD, NOTIFY_REG);

	$hold	(negedge Di[ 6] , A[ 0],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[ 1],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[ 2],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[ 3],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[ 4],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[ 5],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[ 6],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[ 7],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[ 8],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[ 9],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[10],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[11],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[12],  A_D_HD, NOTIFY_REG); 
	$hold	(negedge Di[ 6] , A[13],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 6] , A[14],  A_D_HD, NOTIFY_REG);

	$hold	(negedge Di[ 7] , A[ 0],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[ 1],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[ 2],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[ 3],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[ 4],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[ 5],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[ 6],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[ 7],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[ 8],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[ 9],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[10],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[11],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[12],  A_D_HD, NOTIFY_REG);	   
	$hold	(negedge Di[ 7] , A[13],  A_D_HD, NOTIFY_REG);
	$hold	(negedge Di[ 7] , A[14],  A_D_HD, NOTIFY_REG);


	$setup	(negedge Di[ 0] , posedge Di[ 0], D_D_SU, NOTIFY_REG);
  $setup	(negedge Di[ 0] , posedge Di[ 1], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 0] , posedge Di[ 2], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 0] , posedge Di[ 3], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 0] , posedge Di[ 4], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 0] , posedge Di[ 5], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 0] , posedge Di[ 6], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 0] , posedge Di[ 7], D_D_SU, NOTIFY_REG);

	$setup	(negedge Di[ 1] , posedge Di[ 0], D_D_SU, NOTIFY_REG);
  $setup	(negedge Di[ 1] , posedge Di[ 1], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 1] , posedge Di[ 2], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 1] , posedge Di[ 3], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 1] , posedge Di[ 4], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 1] , posedge Di[ 5], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 1] , posedge Di[ 6], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 1] , posedge Di[ 7], D_D_SU, NOTIFY_REG);

	$setup	(negedge Di[ 2] , posedge Di[ 0], D_D_SU, NOTIFY_REG);
  $setup	(negedge Di[ 2] , posedge Di[ 1], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 2] , posedge Di[ 2], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 2] , posedge Di[ 3], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 2] , posedge Di[ 4], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 2] , posedge Di[ 5], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 2] , posedge Di[ 6], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 2] , posedge Di[ 7], D_D_SU, NOTIFY_REG);

	$setup	(negedge Di[ 3] , posedge Di[ 0], D_D_SU, NOTIFY_REG);
  $setup	(negedge Di[ 3] , posedge Di[ 1], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 3] , posedge Di[ 2], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 3] , posedge Di[ 3], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 3] , posedge Di[ 4], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 3] , posedge Di[ 5], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 3] , posedge Di[ 6], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 3] , posedge Di[ 7], D_D_SU, NOTIFY_REG);

	$setup	(negedge Di[ 4] , posedge Di[ 0], D_D_SU, NOTIFY_REG);
  $setup	(negedge Di[ 4] , posedge Di[ 1], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 4] , posedge Di[ 2], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 4] , posedge Di[ 3], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 4] , posedge Di[ 4], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 4] , posedge Di[ 5], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 4] , posedge Di[ 6], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 4] , posedge Di[ 7], D_D_SU, NOTIFY_REG);

	$setup	(negedge Di[ 5] , posedge Di[ 0], D_D_SU, NOTIFY_REG);
  $setup	(negedge Di[ 5] , posedge Di[ 1], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 5] , posedge Di[ 2], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 5] , posedge Di[ 3], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 5] , posedge Di[ 4], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 5] , posedge Di[ 5], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 5] , posedge Di[ 6], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 5] , posedge Di[ 7], D_D_SU, NOTIFY_REG);

	$setup	(negedge Di[ 6] , posedge Di[ 0], D_D_SU, NOTIFY_REG);
  $setup	(negedge Di[ 6] , posedge Di[ 1], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 6] , posedge Di[ 2], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 6] , posedge Di[ 3], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 6] , posedge Di[ 4], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 6] , posedge Di[ 5], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 6] , posedge Di[ 6], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 6] , posedge Di[ 7], D_D_SU, NOTIFY_REG);

	$setup	(negedge Di[ 7] , posedge Di[ 0], D_D_SU, NOTIFY_REG);
  $setup	(negedge Di[ 7] , posedge Di[ 1], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 7] , posedge Di[ 2], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 7] , posedge Di[ 3], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 7] , posedge Di[ 4], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 7] , posedge Di[ 5], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 7] , posedge Di[ 6], D_D_SU, NOTIFY_REG);
	$setup	(negedge Di[ 7] , posedge Di[ 7], D_D_SU, NOTIFY_REG);


	$width		(posedge Di[ 7], D_PWH, 0, NOTIFY_REG);
	$width		(posedge Di[ 6], D_PWH, 0, NOTIFY_REG);
	$width		(posedge Di[ 5], D_PWH, 0, NOTIFY_REG);
	$width		(posedge Di[ 4], D_PWH, 0, NOTIFY_REG);
	$width		(posedge Di[ 3], D_PWH, 0, NOTIFY_REG);
	$width		(posedge Di[ 2], D_PWH, 0, NOTIFY_REG);
	$width		(posedge Di[ 1], D_PWH, 0, NOTIFY_REG);
	$width		(posedge Di[ 0], D_PWH, 0, NOTIFY_REG);

endspecify

endmodule
